@@ -1,13 +1,3 @@
-# matching.py - bipartite graph maximum matching algorithms
-#
-# Copyright 2015 Jeffrey Finkelstein <jeffrey.finkelstein@gmail.com>,
-# Copyright 2019 Søren Fuglede Jørgensen
-#
-# This file is part of NetworkX.
-#
-# NetworkX is distributed under a BSD license; see LICENSE.txt for more
-# information.
-#
 # This module uses material from the Wikipedia article Hopcroft--Karp algorithm
 # <https://en.wikipedia.org/wiki/Hopcroft%E2%80%93Karp_algorithm>, accessed on
 # January 3, 2015, which is released under the Creative Commons
@@ -28,7 +18,6 @@ import one of the named maximum matching algorithms directly.
 For example, to find a maximum matching in the complete bipartite graph with
 two vertices on the left and three vertices on the right:
 
->>> import networkx as nx
 >>> G = nx.complete_bipartite_graph(2, 3)
 >>> left, right = nx.bipartite.sets(G)
 >>> list(left)
@@ -54,22 +43,35 @@ from networkx.algorithms.bipartite.matrix import biadjacency_matrix
 from networkx.algorithms.bipartite import sets as bipartite_sets
 import networkx as nx
 
-__all__ = ['maximum_matching', 'hopcroft_karp_matching', 'eppstein_matching',
-           'to_vertex_cover', 'minimum_weight_full_matching']
+__all__ = [
+    "maximum_matching",
+    "hopcroft_karp_matching",
+    "eppstein_matching",
+    "to_vertex_cover",
+    "minimum_weight_full_matching",
+]
 
-INFINITY = float('inf')
+INFINITY = float("inf")
 
 
 def hopcroft_karp_matching(G, top_nodes=None):
     """Returns the maximum cardinality matching of the bipartite graph `G`.
 
+    A matching is a set of edges that do not share any nodes. A maximum
+    cardinality matching is a matching with the most edges possible. It
+    is not always unique. Finding a matching in a bipartite graph can be
+    treated as a networkx flow problem.
+
+    The functions ``hopcroft_karp_matching`` and ``maximum_matching``
+    are aliases of the same function.
+
     Parameters
     ----------
     G : NetworkX graph
 
       Undirected bipartite graph
 
-    top_nodes : container
+    top_nodes : container of nodes
 
       Container with all nodes in one bipartite node set. If not supplied
       it will be computed. But if more than one solution exists an exception
@@ -81,12 +83,11 @@ def hopcroft_karp_matching(G, top_nodes=None):
 
       The matching is returned as a dictionary, `matches`, such that
       ``matches[v] == w`` if node `v` is matched to node `w`. Unmatched
-      nodes do not occur as a key in mate.
+      nodes do not occur as a key in `matches`.
 
     Raises
     ------
-    AmbiguousSolution : Exception
-
+    AmbiguousSolution
       Raised if the input bipartite graph is disconnected and no container
       with all nodes in one bipartite set is provided. When determining
       the nodes in each bipartite set more than one valid solution is
@@ -103,7 +104,8 @@ def hopcroft_karp_matching(G, top_nodes=None):
 
     See Also
     --------
-
+    maximum_matching
+    hopcroft_karp_matching
     eppstein_matching
 
     References
@@ -198,12 +200,11 @@ def eppstein_matching(G, top_nodes=None):
 
       The matching is returned as a dictionary, `matching`, such that
       ``matching[v] == w`` if node `v` is matched to node `w`. Unmatched
-      nodes do not occur as a key in mate.
+      nodes do not occur as a key in `matching`.
 
     Raises
     ------
-    AmbiguousSolution : Exception
-
+    AmbiguousSolution
       Raised if the input bipartite graph is disconnected and no container
       with all nodes in one bipartite set is provided. When determining
       the nodes in each bipartite set more than one valid solution is
@@ -311,8 +312,7 @@ def eppstein_matching(G, top_nodes=None):
             recurse(v)
 
 
-def _is_connected_by_alternating_path(G, v, matched_edges, unmatched_edges,
-                                      targets):
+def _is_connected_by_alternating_path(G, v, matched_edges, unmatched_edges, targets):
     """Returns True if and only if the vertex `v` is connected to one of
     the target vertices by an alternating path in `G`.
 
@@ -334,6 +334,7 @@ def _is_connected_by_alternating_path(G, v, matched_edges, unmatched_edges,
     `targets` is a set of vertices.
 
     """
+
     def _alternating_dfs(u, along_matched=True):
         """Returns True if and only if `u` is connected to one of the
         targets by an alternating path.
@@ -345,23 +346,22 @@ def _is_connected_by_alternating_path(G, v, matched_edges, unmatched_edges,
         will continue only through edges *not* in the given matching.
 
         """
-        if along_matched:
-            edges = itertools.cycle([matched_edges, unmatched_edges])
-        else:
-            edges = itertools.cycle([unmatched_edges, matched_edges])
         visited = set()
-        stack = [(u, iter(G[u]), next(edges))]
+        # Follow matched edges when depth is even,
+        # and follow unmatched edges when depth is odd.
+        initial_depth = 0 if along_matched else 1
+        stack = [(u, iter(G[u]), initial_depth)]
         while stack:
-            parent, children, valid_edges = stack[-1]
+            parent, children, depth = stack[-1]
+            valid_edges = matched_edges if depth % 2 else unmatched_edges
             try:
                 child = next(children)
                 if child not in visited:
-                    if ((parent, child) in valid_edges
-                            or (child, parent) in valid_edges):
+                    if (parent, child) in valid_edges or (child, parent) in valid_edges:
                         if child in targets:
                             return True
                         visited.add(child)
-                        stack.append((child, iter(G[child]), next(edges)))
+                        stack.append((child, iter(G[child]), depth + 1))
             except StopIteration:
                 stack.pop()
         return False
@@ -369,8 +369,9 @@ def _is_connected_by_alternating_path(G, v, matched_edges, unmatched_edges,
     # Check for alternating paths starting with edges in the matching, then
     # check for alternating paths starting with edges not in the
     # matching.
-    return (_alternating_dfs(v, along_matched=True) or
-            _alternating_dfs(v, along_matched=False))
+    return _alternating_dfs(v, along_matched=True) or _alternating_dfs(
+        v, along_matched=False
+    )
 
 
 def _connected_by_alternating_paths(G, matching, targets):
@@ -397,12 +398,18 @@ def _connected_by_alternating_paths(G, matching, targets):
     # require nodes to be orderable.
     edge_sets = {frozenset((u, v)) for u, v in matching.items()}
     matched_edges = {tuple(edge) for edge in edge_sets}
-    unmatched_edges = {(u, v) for (u, v) in G.edges()
-                       if frozenset((u, v)) not in edge_sets}
+    unmatched_edges = {
+        (u, v) for (u, v) in G.edges() if frozenset((u, v)) not in edge_sets
+    }
 
-    return {v for v in G if v in targets or
-            _is_connected_by_alternating_path(G, v, matched_edges,
-                                              unmatched_edges, targets)}
+    return {
+        v
+        for v in G
+        if v in targets
+        or _is_connected_by_alternating_path(
+            G, v, matched_edges, unmatched_edges, targets
+        )
+    }
 
 
 def to_vertex_cover(G, matching, top_nodes=None):
@@ -436,8 +443,7 @@ def to_vertex_cover(G, matching, top_nodes=None):
 
     Raises
     ------
-    AmbiguousSolution : Exception
-
+    AmbiguousSolution
       Raised if the input bipartite graph is disconnected and no container
       with all nodes in one bipartite set is provided. When determining
       the nodes in each bipartite set more than one valid solution is
@@ -455,7 +461,6 @@ def to_vertex_cover(G, matching, top_nodes=None):
     for any graph, one can compute the maximum independent set of a bipartite
     graph this way:
 
-    >>> import networkx as nx
     >>> G = nx.complete_bipartite_graph(2, 3)
     >>> matching = nx.bipartite.maximum_matching(G)
     >>> vertex_cover = nx.bipartite.to_vertex_cover(G, matching)
@@ -487,20 +492,20 @@ def to_vertex_cover(G, matching, top_nodes=None):
 maximum_matching = hopcroft_karp_matching
 
 
-def minimum_weight_full_matching(G, top_nodes=None, weight='weight'):
-    r"""Returns the minimum weight full matching of the bipartite graph `G`.
+def minimum_weight_full_matching(G, top_nodes=None, weight="weight"):
+    r"""Returns a minimum weight full matching of the bipartite graph `G`.
+
+    Let :math:`G = ((U, V), E)` be a weighted bipartite graph with real weights
+    :math:`w : E \to \mathbb{R}`. This function then produces a matching
+    :math:`M \subseteq E` with cardinality
 
-    Let :math:`G = ((U, V), E)` be a complete weighted bipartite graph with
-    real weights :math:`w : E \to \mathbb{R}`. This function then produces
-    a maximum matching :math:`M \subseteq E` which, since the graph is
-    assumed to be complete, has cardinality
-   
     .. math::
        \lvert M \rvert = \min(\lvert U \rvert, \lvert V \rvert),
 
-    and which minimizes the sum of the weights of the edges included in the
-    matching, :math:`\sum_{e \in M} w(e)`.
-    
+    which minimizes the sum of the weights of the edges included in the
+    matching, :math:`\sum_{e \in M} w(e)`, or raises an error if no such
+    matching exists.
+
     When :math:`\lvert U \rvert = \lvert V \rvert`, this is commonly
     referred to as a perfect matching; here, since we allow
     :math:`\lvert U \rvert` and :math:`\lvert V \rvert` to differ, we
@@ -527,16 +532,14 @@ def minimum_weight_full_matching(G, top_nodes=None, weight='weight'):
 
       The matching is returned as a dictionary, `matches`, such that
       ``matches[v] == w`` if node `v` is matched to node `w`. Unmatched
-      nodes do not occur as a key in matches.
+      nodes do not occur as a key in `matches`.
 
     Raises
     ------
-    ValueError : Exception
-
-      Raised if the input bipartite graph is not complete.
-
-    ImportError : Exception
+    ValueError
+      Raised if no full matching exists.
 
+    ImportError
       Raised if SciPy is not available.
 
     Notes
@@ -553,26 +556,22 @@ def minimum_weight_full_matching(G, top_nodes=None, weight='weight'):
        Networks, 10(2):143–152, 1980.
 
     """
-    try:
-        import scipy.optimize
-    except ImportError:
-        raise ImportError('minimum_weight_full_matching requires SciPy: ' +
-                          'https://scipy.org/')
+    import numpy as np
+    import scipy as sp
+    import scipy.optimize  # call as sp.optimize
+
     left, right = nx.bipartite.sets(G, top_nodes)
-    # Ensure that the graph is complete. This is currently a requirement in
-    # the underlying  optimization algorithm from SciPy, but the constraint
-    # will be removed in SciPy 1.4.0, at which point it can also be removed
-    # here.
-    for (u, v) in itertools.product(left, right):
-        # As the graph is undirected, make sure to check for edges in
-        # both directions
-        if (u, v) not in G.edges() and (v, u) not in G.edges():
-            raise ValueError('The bipartite graph must be complete.')
     U = list(left)
     V = list(right)
-    weights = biadjacency_matrix(G, row_order=U,
-                                 column_order=V, weight=weight).toarray()
-    left_matches = scipy.optimize.linear_sum_assignment(weights)
+    # We explicitly create the biadjancency matrix having infinities
+    # where edges are missing (as opposed to zeros, which is what one would
+    # get by using toarray on the sparse matrix).
+    weights_sparse = biadjacency_matrix(
+        G, row_order=U, column_order=V, weight=weight, format="coo"
+    )
+    weights = np.full(weights_sparse.shape, np.inf)
+    weights[weights_sparse.row, weights_sparse.col] = weights_sparse.data
+    left_matches = sp.optimize.linear_sum_assignment(weights)
     d = {U[u]: V[v] for u, v in zip(*left_matches)}
     # d will contain the matching from edges in left to right; we need to
     # add the ones from right to left as well.
