@@ -46,8 +46,8 @@ def is_k_edge_connected(G, k):
     --------
     :func:`is_locally_k_edge_connected`
 
-    Example
-    -------
+    Examples
+    --------
     >>> G = nx.barbell_graph(10, 0)
     >>> nx.is_k_edge_connected(G, k=1)
     True
@@ -102,8 +102,8 @@ def is_locally_k_edge_connected(G, s, t, k):
     --------
     :func:`is_k_edge_connected`
 
-    Example
-    -------
+    Examples
+    --------
     >>> from networkx.algorithms.connectivity import is_locally_k_edge_connected
     >>> G = nx.barbell_graph(10, 0)
     >>> is_locally_k_edge_connected(G, 5, 15, k=1)
@@ -204,8 +204,8 @@ def k_edge_augmentation(G, k, avail=None, weight=None, partial=False):
         produces a feasible solution, but provides no guarantees on the
         solution weight.
 
-    Example
-    -------
+    Examples
+    --------
     >>> # Unweighted cases
     >>> G = nx.path_graph((1, 2, 3, 4))
     >>> G.add_node(5)
@@ -220,8 +220,6 @@ def k_edge_augmentation(G, k, avail=None, weight=None, partial=False):
     >>> nx.edge_connectivity(G)
     4
 
-    Example
-    -------
     >>> # Weighted cases
     >>> G = nx.path_graph((1, 2, 3, 4))
     >>> G.add_node(5)
@@ -326,8 +324,8 @@ def partial_k_edge_augmentation(G, k, avail, weight=None):
     --------
     :func:`k_edge_augmentation`
 
-    Example
-    -------
+    Examples
+    --------
     >>> G = nx.path_graph((1, 2, 3, 4, 5, 6, 7))
     >>> G.add_node(8)
     >>> avail = [(1, 3), (1, 4), (1, 5), (2, 4), (2, 5), (3, 5), (1, 8)]
@@ -336,7 +334,7 @@ def partial_k_edge_augmentation(G, k, avail, weight=None):
     """
 
     def _edges_between_disjoint(H, only1, only2):
-        """ finds edges between disjoint nodes """
+        """finds edges between disjoint nodes"""
         only1_adj = {u: set(H.adj[u]) for u in only1}
         for u, neighbs in only1_adj.items():
             # Find the neighbors of u in only1 that are also in only2
@@ -547,8 +545,8 @@ def _lightest_meta_edges(mapping, avail_uv, avail_w):
     minimum weight edge bridging each k-edge-connected component so, we group
     the edges by meta-edge and take the lightest in each group.
 
-    Example
-    -------
+    Examples
+    --------
     >>> # Each group represents a meta-node
     >>> groups = ([1, 2, 3], [4, 5], [6])
     >>> mapping = {n: meta_n for meta_n, ns in enumerate(groups) for n in ns}
@@ -594,8 +592,8 @@ def unconstrained_one_edge_augmentation(G):
     :func:`one_edge_augmentation`
     :func:`k_edge_augmentation`
 
-    Example
-    -------
+    Examples
+    --------
     >>> G = nx.Graph([(1, 2), (2, 3), (4, 5)])
     >>> G.add_nodes_from([6, 7, 8])
     >>> sorted(unconstrained_one_edge_augmentation(G))
@@ -646,8 +644,8 @@ def weighted_one_edge_augmentation(G, avail, weight=None, partial=False):
     :func:`one_edge_augmentation`
     :func:`k_edge_augmentation`
 
-    Example
-    -------
+    Examples
+    --------
     >>> G = nx.Graph([(1, 2), (2, 3), (4, 5)])
     >>> G.add_nodes_from([6, 7, 8])
     >>> # any edge not in avail has an implicit weight of infinity
@@ -746,8 +744,8 @@ def unconstrained_bridge_augmentation(G):
     :func:`bridge_augmentation`
     :func:`k_edge_augmentation`
 
-    Example
-    -------
+    Examples
+    --------
     >>> G = nx.path_graph((1, 2, 3, 4, 5, 6, 7))
     >>> sorted(unconstrained_bridge_augmentation(G))
     [(1, 7)]
@@ -880,8 +878,8 @@ def weighted_bridge_augmentation(G, avail, weight=None):
     :func:`bridge_augmentation`
     :func:`k_edge_augmentation`
 
-    Example
-    -------
+    Examples
+    --------
     >>> G = nx.path_graph((1, 2, 3, 4))
     >>> # When the weights are equal, (1, 4) is the best
     >>> avail = [(1, 4, 1), (1, 3, 1), (2, 4, 1)]
@@ -1021,7 +1019,7 @@ def _minimum_rooted_branching(D, root):
     References
     ----------
     [1] Khuller, Samir (2002) Advanced Algorithms Lecture 24 Notes.
-    https://www.cs.umd.edu/class/spring2011/cmsc651/lec07.pdf
+    https://web.archive.org/web/20121030033722/https://www.cs.umd.edu/class/spring2011/cmsc651/lec07.pdf
     """
     rooted = D.copy()
     # root the graph by removing all predecessors to `root`.
@@ -1114,8 +1112,8 @@ def complement_edges(G):
     edge : tuple
         Edges in the complement of G
 
-    Example
-    -------
+    Examples
+    --------
     >>> G = nx.path_graph((1, 2, 3, 4))
     >>> sorted(complement_edges(G))
     [(1, 3), (1, 4), (2, 4)]
@@ -1187,8 +1185,8 @@ def greedy_k_edge_augmentation(G, k, avail=None, weight=None, seed=None):
     --------
     :func:`k_edge_augmentation`
 
-    Example
-    -------
+    Examples
+    --------
     >>> G = nx.path_graph((1, 2, 3, 4, 5, 6, 7))
     >>> sorted(greedy_k_edge_augmentation(G, k=2))
     [(1, 7)]
