@@ -1,69 +1,79 @@
-# -*- coding: utf-8 -*-
 """Floyd-Warshall algorithm for shortest paths.
 """
-#    Copyright (C) 2004-2019 by
-#    Aric Hagberg <hagberg@lanl.gov>
-#    Dan Schult <dschult@colgate.edu>
-#    Pieter Swart <swart@lanl.gov>
-#    All rights reserved.
-#    BSD license.
-#
-# Authors: Aric Hagberg <aric.hagberg@gmail.com>
-#          Miguel Sozinho Ramalho <m.ramalho@fe.up.pt>
 import networkx as nx
 
-__all__ = ['floyd_warshall',
-           'floyd_warshall_predecessor_and_distance',
-           'reconstruct_path',
-           'floyd_warshall_numpy']
+__all__ = [
+    "floyd_warshall",
+    "floyd_warshall_predecessor_and_distance",
+    "reconstruct_path",
+    "floyd_warshall_numpy",
+]
 
 
-def floyd_warshall_numpy(G, nodelist=None, weight='weight'):
+def floyd_warshall_numpy(G, nodelist=None, weight="weight"):
     """Find all-pairs shortest path lengths using Floyd's algorithm.
 
+    This algorithm for finding shortest paths takes advantage of
+    matrix representations of a graph and works well for dense
+    graphs where all-pairs shortest path lengths are desired.
+    The results are returned as a NumPy array, distance[i, j],
+    where i and j are the indexes of two nodes in nodelist.
+    The entry distance[i, j] is the distance along a shortest
+    path from i to j. If no path exists the distance is Inf.
+
     Parameters
     ----------
     G : NetworkX graph
 
-    nodelist : list, optional
+    nodelist : list, optional (default=G.nodes)
        The rows and columns are ordered by the nodes in nodelist.
-       If nodelist is None then the ordering is produced by G.nodes().
+       If nodelist is None then the ordering is produced by G.nodes.
+       Nodelist should include all nodes in G.
 
-    weight: string, optional (default= 'weight')
+    weight: string, optional (default='weight')
        Edge data key corresponding to the edge weight.
 
     Returns
     -------
     distance : NumPy matrix
         A matrix of shortest path distances between nodes.
-        If there is no path between to nodes the corresponding matrix entry
-        will be Inf.
+        If there is no path between two nodes the value is Inf.
 
     Notes
-    ------
+    -----
     Floyd's algorithm is appropriate for finding shortest paths in
     dense graphs or graphs with negative weights when Dijkstra's
     algorithm fails. This algorithm can still fail if there are negative
-    cycles.  It has running time $O(n^3)$ with running space of $O(n^2)$.
+    cycles. It has running time $O(n^3)$ with running space of $O(n^2)$.
+
+    Raises
+    ------
+    NetworkXError
+        If nodelist is not a list of the nodes in G.
     """
-    try:
-        import numpy as np
-    except ImportError:
-        raise ImportError(
-            "to_numpy_matrix() requires numpy: http://scipy.org/ ")
+    import numpy as np
+
+    if nodelist is not None:
+        if not (len(nodelist) == len(G) == len(set(nodelist))):
+            raise nx.NetworkXError(
+                "nodelist must contain every node in G with no repeats."
+                "If you wanted a subgraph of G use G.subgraph(nodelist)"
+            )
 
     # To handle cases when an edge has weight=0, we must make sure that
     # nonedges are not given the value 0 as well.
-    A = nx.to_numpy_matrix(G, nodelist=nodelist, multigraph_weight=min,
-                           weight=weight, nonedge=np.inf)
+    A = nx.to_numpy_array(
+        G, nodelist, multigraph_weight=min, weight=weight, nonedge=np.inf
+    )
     n, m = A.shape
-    A[np.identity(n) == 1] = 0  # diagonal elements should be zero
+    np.fill_diagonal(A, 0)  # diagonal elements should be zero
     for i in range(n):
-        A = np.minimum(A, A[i, :] + A[:, i])
+        # The second term has the same shape as A due to broadcasting
+        A = np.minimum(A, A[i, :][np.newaxis, :] + A[:, i][:, np.newaxis])
     return A
 
 
-def floyd_warshall_predecessor_and_distance(G, weight='weight'):
+def floyd_warshall_predecessor_and_distance(G, weight="weight"):
     """Find all-pairs shortest path lengths using Floyd's algorithm.
 
     Parameters
@@ -82,15 +92,26 @@ def floyd_warshall_predecessor_and_distance(G, weight='weight'):
     Examples
     --------
     >>> G = nx.DiGraph()
-    >>> G.add_weighted_edges_from([('s', 'u', 10), ('s', 'x', 5),
-    ...     ('u', 'v', 1), ('u', 'x', 2), ('v', 'y', 1), ('x', 'u', 3),
-    ...     ('x', 'v', 5), ('x', 'y', 2), ('y', 's', 7), ('y', 'v', 6)])
+    >>> G.add_weighted_edges_from(
+    ...     [
+    ...         ("s", "u", 10),
+    ...         ("s", "x", 5),
+    ...         ("u", "v", 1),
+    ...         ("u", "x", 2),
+    ...         ("v", "y", 1),
+    ...         ("x", "u", 3),
+    ...         ("x", "v", 5),
+    ...         ("x", "y", 2),
+    ...         ("y", "s", 7),
+    ...         ("y", "v", 6),
+    ...     ]
+    ... )
     >>> predecessors, _ = nx.floyd_warshall_predecessor_and_distance(G)
-    >>> print(nx.reconstruct_path('s', 'v', predecessors))
+    >>> print(nx.reconstruct_path("s", "v", predecessors))
     ['s', 'x', 'u', 'v']
 
     Notes
-    ------
+    -----
     Floyd's algorithm is appropriate for finding shortest paths
     in dense graphs or graphs with negative weights when Dijkstra's algorithm
     fails.  This algorithm can still fail if there are negative cycles.
@@ -104,10 +125,11 @@ def floyd_warshall_predecessor_and_distance(G, weight='weight'):
     all_pairs_shortest_path_length
     """
     from collections import defaultdict
+
     # dictionary-of-dictionaries representation for dist and pred
     # use some defaultdict magick here
     # for dist the default is the floating point inf value
-    dist = defaultdict(lambda: defaultdict(lambda: float('inf')))
+    dist = defaultdict(lambda: defaultdict(lambda: float("inf")))
     for u in G:
         dist[u][u] = 0
     pred = defaultdict(dict)
@@ -157,7 +179,7 @@ def reconstruct_path(source, target, predecessors):
        If source and target are the same, an empty list is returned
 
     Notes
-    ------
+    -----
     This function is meant to give more applicability to the
     floyd_warshall_predecessor_and_distance function
 
@@ -176,7 +198,7 @@ def reconstruct_path(source, target, predecessors):
     return list(reversed(path))
 
 
-def floyd_warshall(G, weight='weight'):
+def floyd_warshall(G, weight="weight"):
     """Find all-pairs shortest path lengths using Floyd's algorithm.
 
     Parameters
@@ -194,7 +216,7 @@ def floyd_warshall(G, weight='weight'):
        between nodes.
 
     Notes
-    ------
+    -----
     Floyd's algorithm is appropriate for finding shortest paths
     in dense graphs or graphs with negative weights when Dijkstra's algorithm
     fails.  This algorithm can still fail if there are negative cycles.
@@ -209,9 +231,3 @@ def floyd_warshall(G, weight='weight'):
     """
     # could make this its own function to reduce memory costs
     return floyd_warshall_predecessor_and_distance(G, weight=weight)[1]
-
-
-# fixture for pytest
-def setup_module(module):
-    import pytest
-    numpy = pytest.importorskip('numpy')
