@@ -10,7 +10,7 @@ import matplotlib.pyplot as plt
 import networkx as nx
 
 G = nx.star_graph(20)
-pos = nx.spring_layout(G)
+pos = nx.spring_layout(G, seed=63)  # Seed layout for reproducibility
 colors = range(20)
 options = {
     "node_color": "#A0CBE2",
